summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--utils/sbtools/elf.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/utils/sbtools/elf.c b/utils/sbtools/elf.c
index 80bff01..896c9cb 100644
--- a/utils/sbtools/elf.c
+++ b/utils/sbtools/elf.c
@@ -272,10 +272,10 @@ void elf_write_file(struct elf_params_t *params, elf_write_fn_t write, void *use
/* allocate enough size to hold any combinaison of .text/.bss in the string table:
* - one empty name ("\0")
* - at most N names of the form ".textXX\0" or ".bssXX\0"
* - one name ".shstrtab\0" */
char *strtbl_content = malloc(1 + strlen(".shstrtab") + 1 +
- phnum * (strlen(".textXX") + 1));
+ phnum * (strlen(".textXXXX") + 1));
strtbl_content[0] = '\0';
strcpy(&strtbl_content[1], ".shstrtab");
@@ -272,10 +272,10 @@ void elf_write_file(struct elf_params_t *params, elf_write_fn_t write, void *use
/* allocate enough size to hold any combinaison of .text/.bss in the string table:
* - one empty name ("\0")
- * - at most N names of the form ".textXX\0" or ".bssXX\0"
+ * - at most N names of the form ".textXXXX\0" or ".bssXXXX\0"
* - one name ".shstrtab\0" */
char *strtbl_content = malloc(1 + strlen(".shstrtab") + 1 +